@@ -27,6 +27,7 @@ def get_parser():
     parser.add_argument("--display-json", metavar="ssr_id", type=int, help="display ssr json info")
     parser.add_argument("--test-speed", type=int, metavar="ssr_id", help="test ssr nodes download and upload speed")
     parser.add_argument("--test-netflix", type=int, metavar="ssr_id", help="test ssr nodes if or not watch netflix")
+    parser.add_argument("--test-netflix-all", action="store_true", help="test all ssr nodes if or not watch netflix")
     parser.add_argument("--fast-node", action="store_true", help="find most fast by delay and start ssr proxy")
     parser.add_argument("--setting-url", metavar="ssr_subscribe_url", help="setting ssr subscribe url")
     parser.add_argument("--setting-address", metavar="ssr_local_address", help="setting ssr local address")
@@ -95,6 +96,8 @@ def main():
         DisplayShadowsocksr.display_shadowsocksr_speed(ssr_id=args.test_speed)
     elif args.test_netflix is not None:
         DisplayShadowsocksr.display_shadowsocksr_netflix(ssr_id=args.test_netflix)
+    elif args.test_netflix_all:
+        DisplayShadowsocksr.display_all_shadowsocksr_netflix()
     elif args.display_json is not None:
         DisplayShadowsocksr.display_shadowsocksr_json(ssr_id=args.display_json)
     elif args.generate_clash:
